#!/bin/bash

# Source1 : http://www.eca.cx/ecasound/
# Source2 : http://sourceforge.net/projects/tkeca/
# Packager : JP Guillemin jp.guillemin@free.fr

soft='ecasound'
softversion='2.4.6.1'
packageversion='52.1'

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

srcpkg2="$buildir/tkeca-4.2.0.tar.gz"
src2="$buildir/tkeca-4.2.0"

cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest
chown -R root:root .

# Description file
mkdir -p $dest/install

cat << "EODESC" > $dest/install/slack-desc
ecasound: ecasound - Multitrack Recorder / Sound Processor
ecasound:
ecasound: Ecasound is a software package designed for multitrack 
ecasound: audio processing. It can be used for simple tasks like 
ecasound: audio playback, recording and format conversions, as well 
ecasound: as for multitrack effect processing, mixing, recording and 
ecasound: signal recycling. Ecasound supports a wide range of audio 
ecasound: inputs, outputs and effect algorithms. 
ecasound:
ecasound:
EODESC

export CFLAGS="-O2 -march=$arch -mtune=$cpu"

cd $src
./configure --prefix=/usr --sysconfdir=/etc --localstatedir=/var --mandir=/usr/man
make DESTDIR=$dest
make install DESTDIR=$dest


( cd $dest
  find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded
)
( cd $dest/usr/man
  find . -name "*.?" | xargs gzip -9
)

# Documentation
mkdir -p $dest/usr/doc/$soft-$softversion
cp -a AUTHORS COPYING INSTALL README ChangeLog $dest/usr/doc/$soft-$softversion
mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion


# The frontend #######################""

cd $buildir
rm -rf $src2
tar -xvf $srcpkg2
(
cd $src2
cp tkeca.tcl $dest/usr/bin/tkeca
chmod 755 $dest/usr/bin/tkeca
cp tkeca.html README.tkeca $dest/usr/doc/$soft-$softversion
)
mkdir -p $dest/usr/share/icons/hicolor/scalable/apps
cp $buildir/ecasound.svg $dest/usr/share/icons/hicolor/scalable/apps/


# Desktop file
mkdir -p $dest/usr/share/applications
rm -rf $dest/usr/share/gnome
cat << "EOF" > $dest/usr/share/applications/EcaSound.desktop
[Desktop Entry]
Version=1.0
Type=Application
Encoding=UTF-8
Name=EcaSound
GenericName=EcaSound
Icon=ecasound
TryExec=tkeca
Exec=tkeca
Terminal=false
Categories=X-XFCE;Application;AudioVideo;AudioPlayer;VideoPlayer;
StartupNotify=true
EOF

# redundant
rm -rf $dest/usr/share/doc

# Packaging
cd $dest
makepkg -l y -c n $dest.tgz


